"""Module entry point for :mod:`anyqats.app`.

Executing ``python -m anyqats.app`` will invoke :func:`anyqats.app.main` and
start the graphical user interface.
"""

from . import main

if __name__ == "__main__":
    main()
